import { UploadFile } from 'antd';
import React from 'react';
import { chunkData, ProgressData, UploadProps } from './components';
import { ITableAttachmentApi, ITableAttachmentProps } from './interface';
import { getTempAttachment } from './service';
export declare const DEFAULT_ATTACHMENT_UPLOAD_MAX_COUNT = 99;
export interface IAttachmentContext {
    mergeChunks: (md5: string, totalChunks: number) => Promise<{
        fileId?: string;
    }>;
    upload: (data: chunkData) => Promise<void>;
    beforeUploadValidate: (file: File, fileList: File[]) => Promise<boolean>;
    accept?: string;
    maxCount: number;
    disabled?: boolean;
    uploadThreadCount: number;
    chunkSize: number;
    actions: {
        delete: (data: AttachmentFile[]) => Promise<boolean>;
        zipDownload: () => Promise<void>;
        isPreview: (name: string) => boolean;
        preview: (fileId: string) => Promise<void>;
        download: (data: any) => Promise<void>;
        openTableAttachment: (configs: any) => Promise<any>;
    };
    onContentChanged?: () => void;
    attachmentRecordList: Awaited<ReturnType<typeof getTempAttachment>>;
    loading: boolean;
    permission: ITableAttachmentProps['permission'];
    isReady?: boolean;
    uploading?: boolean;
    attachmentFileList: AttachmentFile[];
    onUploadStateChange: UploadProps['onUploadStateChange'];
    apiRef?: React.MutableRefObject<ITableAttachmentApi>;
    approved: 0 | 1;
}
export declare const AttachmentContext: React.Context<IAttachmentContext>;
export type AttachmentProviderProps = ITableAttachmentProps & {
    children: React.ReactNode;
    disabled?: boolean;
    value?: string;
    onChange?: (v: string) => void;
};
export type UploadedFile = IAttachmentContext['attachmentRecordList'][number] & {
    fileName: string;
    status: UploadFile['status'];
};
export type AttachmentFile = ProgressData | UploadedFile;
export declare const AttachmentProvider: React.ForwardRefExoticComponent<ITableAttachmentProps & {
    children: React.ReactNode;
    disabled?: boolean | undefined;
    value?: string | undefined;
    onChange?: ((v: string) => void) | undefined;
} & React.RefAttributes<unknown>>;
export declare const useAttachment: () => IAttachmentContext;
