import React, { ReactNode } from 'react';
import { read, utils } from 'xlsx';
import { type IModalParamProps } from '../../functionalComponent';
import { type IObject, type PromiseType } from '../../util';
import { type GridPropsType } from './grid';
interface LabeledValue {
    value: string;
    label: React.ReactNode;
}
export interface ImportGridProps extends GridPropsType {
    /**
     * @description        表头属性
     */
    header: {
        /**
         * @description       excel列的待选数据源
         */
        source: LabeledValue[] | ((sheetIndex: number) => PromiseType<LabeledValue[]>);
        /**
         * @description       数据源选择后回调事件
         */
        onChange?: ({}: {}) => {};
        /**
         * @description       表头所在行
         * @default           -1
         */
        index?: number;
        /**
         * @description       列宽
         * @default           100
         */
        width?: number;
        /**
         * @description       默认绑定列字段
         * @default           100
         */
        bindFields?: IObject<string>;
    };
    /**
     * @description        顶部功能区域扩展
     */
    topArea?: ReactNode;
    /**
     * @description         转换excel数据源
     */
    convertData?: (dataSource: any) => Array<any>;
    /**
     * @description         excel sheet页数据切换后回调事件
     */
    onSheetDataChange?: (dataSource: any, currentSheet: any) => void;
    /**
     * @description         合并单元格数据的拆分
     * @default             true
     */
    mergeSplit?: boolean | 'row' | 'column';
}
declare const InternalImportGrid: React.ForwardRefExoticComponent<Omit<ImportGridProps & {
    id?: string | undefined;
}, "outRef"> & React.RefAttributes<import("@cscec/udp-core/src/interface/types/ts.lib").ICurrentObject<any>>>;
type InternalImportGridType = typeof InternalImportGrid;
interface ImportGridInterface extends InternalImportGridType {
    xlsx: {
        utils: typeof utils;
        read: typeof read;
    };
    modal: (params: Partial<IModalParamProps> & {
        gridProps: ImportGridProps;
    }) => Promise<[boolean, any[]]>;
}
declare const ImportGrid: ImportGridInterface;
export { ImportGrid };
