import React, { CSSProperties, ReactNode } from 'react';
import { type IFullPageProps } from '../fullPage';
/**
 * 容器组件
 */
export declare const Panel: React.ForwardRefExoticComponent<IPanel & React.RefAttributes<{
    setFullPage(full: boolean): void;
}>>;
export interface IPanel {
    /**
     * @description       标题
     */
    title?: ReactNode;
    /**
     * @description       标题扩展内容
     */
    extra?: ReactNode;
    blankStyle?: CSSProperties;
    /**
     * @description       内容
     */
    children?: ReactNode;
    /**
     * @description       整体样式
     */
    style?: CSSProperties;
    /**
     * @description       内容样式
     */
    bodyStyle?: CSSProperties;
    /**
     * @description       头部样式
     */
    headerStyle?: CSSProperties;
    className?: string;
    /**
     * @description       容器是否自适应父容器高度
     */
    autoFit?: boolean;
    /**
     * @description       是否支持全屏
     */
    fullScreen?: boolean | Partial<IFullPageProps>;
    /**
     * @description       内容区域的flex布局方向direction
     */
    flexDirection?: 'column' | 'row';
    /**
     * @description       是否可折叠
     * @default           false
     */
    collapsible?: boolean;
    /**
     * @description       是否展示当前面板上的箭头（collapsible 为true有效）
     * @default           true
     */
    showArrow?: boolean;
    /**
     * @description       展开状态（collapsible 为true有效）
     * @default           true
     */
    open?: boolean;
    /**
     * @description       展开状态切换时（collapsible 为true有效）
     */
    onOpenChange?(open: boolean): void;
    /**
     * @description       是否标题前面的竖杠标记
     * @default           true
     */
    showPrefix?: boolean;
    /**
     * @description       紧凑模式
     * @default           false
     */
    compact?: boolean;
}
