/// <reference types="react" />
import { type TableInstance, type TableProps } from '../../functionalComponent/table';
interface IResult<P> {
    isChanged: boolean;
    table: P;
}
declare type NewDataType = {
    key: string;
    newRow: Array<Record<string, any>>;
};
declare type ChangeDataType = NewDataType & {
    modifiedRow: Array<Record<string, any>>;
    deletedRow: Array<Record<string, any>>;
};
export interface ITableInstance extends TableInstance {
    /**
     * @description              返回行状态全是新增的json格式数据【返回格式同ExtUx.js的GetAllGridData方法】
     */
    getAllDataForNew: () => IResult<NewDataType>;
    /**
     * @description        返回所有数据行，包含行状态
     */
    getAllData: (ignoreUnChanged?: boolean) => IResult<ChangeDataType & {
        unChangedRow: Array<Record<string, any>>;
    }>;
    /**
     * @description        返回更新的行
     */
    getChange: (config: {
        initRows?: any[];
        flatSubTable?: boolean;
        ignoreUnChanged?: boolean;
    }) => IResult<ChangeDataType>;
    /**
     * @description        数据源是否变化
     * @default            false
     */
    isChanged: () => boolean;
}
export interface GridPropsType extends TableProps {
    /**
     * @description        业务主键，多个用英文逗号分隔
     */
    busKey?: string;
    /**
     * @description       业务字段，用于返回数据行时字段过滤（默认返回全部字段）
     */
    busFields?: Array<string>;
}
/**
 * 面向业务的Grid组件
 * @param busKey 业务主键
 * @param busFields 业务字段，用于返回数据行时字段过滤（默认返回全部字段）
 */
export declare const Grid: import("react").ForwardRefExoticComponent<Omit<GridPropsType & {
    id?: string | undefined;
}, "outRef"> & import("react").RefAttributes<import("@cscec/udp-core/src/interface/types/ts.lib").ICurrentObject<any>>>;
export {};
