import React from 'react';
import { TableSelectionModel } from './base/common';
import './index.less';
import type { ColumnProps, TableInstance, TablePropsType } from './interface';
import { IObject } from './util';
export declare const TableSymbol: {
    TREE_LEVEL: symbol;
    TREE_INDEX: symbol;
    TREE_LAST_CHILD: symbol;
    TREE_PARENT: symbol;
    GROUP_PARENT: symbol;
    TREE_LEAF_NODE: symbol;
};
export { TableSelectionModel };
export type { ColumnProps, TableInstance };
declare const defaultProps: {
    /**
     * @description       紧凑表格
     * @default           false
     */
    compact: boolean;
    /**
     * @description       表格延迟resize的毫秒数
     * @default           16
     */
    resizeDelay: number;
    /**
     * @description       是否加载中
     * @default           false
     */
    loading: boolean;
    /**
     * @description       配置request属性，是否自动加载数据
     * @default           true
     */
    autoLoad: boolean;
    /**
     * @description       是否树形列表
     * @default           false
     */
    isTree: boolean;
    /**
     * @description       是否显示单元格边框
     * @default           false
     */
    bordered: boolean;
    /**
     * @description       是否隐藏表头
     * @default           false
     */
    hiddenHeader: boolean;
    /**
     * @description       是否支持单击行选中checkbox
     * @default           false
     */
    rowChecked: boolean;
    /**
     * @description       点击数据行高亮选中行
     * @default           true
     */
    rowSelected: boolean;
    /**
     * @description       点击checkbox列高亮选中行
     * @default           false
     */
    checkboxSelected: boolean;
    /**
     * @description       是否启用虚拟滚动，建议开启；如果需要高度随内容自动撑开，设置false
     * @default           true
     */
    virtualScrolling: boolean;
    /**
     * @description       编辑状态，是否支持最后一行按"下方向键"及最后一列按"回车"或"tab"自动增加行
     * @default           false
     */
    keyBoardToAddRow: boolean;
    /**
     * @description       编辑状态，键盘事件的是否绑定在document上，注意多个Grid会产生冲突
     * @default           false
     */
    listenerOnDocument: boolean;
    /**
     * @description       是否开启记忆列状态功能
     * @default           true
     */
    remember: boolean;
};
export type TableProps = TablePropsType<typeof defaultProps>;
export declare const Table: React.ForwardRefExoticComponent<Omit<{
    editCellHighlight?: string | boolean | undefined;
    cacheRaw?: boolean | undefined;
    rowFilter?: string | ((row: IObject) => boolean) | undefined;
    tabIndex?: number | undefined;
    autoScroll?: boolean | undefined;
    stateId?: string | undefined;
    cache?: boolean | ("column" | "page" | "selected")[] | undefined;
    editColumnIcon?: boolean | (({ table, dataIndex, editor, style }: {
        table: any;
        dataIndex: any;
        editor: any;
        style: any;
    }) => React.ReactNode) | undefined;
    keyField?: string | undefined;
    expandField?: string | undefined;
    expandCfg?: {
        icon?: ((expanded: boolean) => React.ReactNode) | undefined;
        dataIndex?: string | undefined;
        width?: number | undefined;
        fixed?: boolean | undefined;
        defaultExpand?: number | "all" | ((param: {
            row: any;
            index: any;
            level?: any;
        }) => boolean) | undefined;
        fitContent?: boolean | undefined;
        showLine?: boolean | undefined;
        block?: boolean | undefined;
    } | undefined;
    className?: string | undefined;
    style?: React.CSSProperties | undefined;
    columns?: ColumnProps[] | undefined;
    headerMenu?: boolean | {
        icon?: React.ReactNode;
        getContainer?: string | (() => Element | null) | undefined;
        inTableAlert?: boolean | undefined;
    } | (({ table }: {
        table: any;
    }) => React.ReactNode) | undefined;
    defaultLoading?: boolean | undefined;
    dataSource?: object[] | undefined;
    defaultSelectedRowIndex?: number | ((ds: any[]) => number) | undefined;
    showRowNumber?: boolean | (Partial<ColumnProps> & {
        editOptions?: {
            disabled?: ((params: {
                table: TableInstance;
                rowIndex: number;
            }) => boolean | ("add" | "delete")[]) | undefined;
            add?: ((params: {
                table: TableInstance;
                rowIndex: number;
            }) => import("@cscec/udp-core/src/interface/types/ts.lib").PromiseType<void>) | undefined;
            delete?: ((params: {
                table: TableInstance;
                rowIndex: number;
            }) => import("@cscec/udp-core/src/interface/types/ts.lib").PromiseType<void>) | undefined;
        } | undefined;
    }) | undefined;
    checkbox?: string | boolean | undefined;
    onCheckedChange?: ((...args: any[]) => void) | undefined;
    onKeyDown?: ((params: {
        keyCode: number;
    }) => void) | undefined;
    rowHeight?: number | ((rowIndex: number) => number) | "auto" | undefined;
    estimateRowHeight?: boolean | {
        fontSize?: string | number | undefined;
        lineHeight?: string | number | undefined;
    } | undefined;
    headerHeight?: number | undefined;
    expandRow?: {
        height: number | (({ row, rowIndex }: {
            row: any;
            rowIndex: any;
        }) => number);
        render: ({ row, rowIndex, table, style }: {
            row: any;
            rowIndex: any;
            table: any;
            style: any;
        }) => React.ReactNode;
    } | undefined;
    onRow?: ((rowIndex: number, table: any, row: IObject) => IObject) | undefined;
    rowContextMenu?: ((row: IObject, extra: {
        table: TableInstance;
        rowIndex?: number | undefined;
        hidden: Function;
        dataIndex?: string | undefined;
    }) => React.ReactElement<any, string | React.JSXElementConstructor<any>>) | undefined;
    bodyContextMenu?: ((params: {
        table: TableInstance;
        rowIndex?: number | undefined;
        hidden: Function;
        dataIndex?: string | undefined;
    }) => React.ReactElement<any, string | React.JSXElementConstructor<any>>) | undefined;
    rowDrag?: boolean | {
        pressDelay?: number | undefined;
        handleIndex?: string | undefined;
        listeners?: {
            shouldCancelStart?(e: any, rowIndex: any): boolean;
            onSortStart?({ node, index, collection, isKeySorting }: {
                node: any;
                index: any;
                collection: any;
                isKeySorting: any;
            }, event: any): void;
            onSortMove?(event: any): void;
            onSortOver?({ index, oldIndex, newIndex, collection, isKeySorting }: {
                index: any;
                oldIndex: any;
                newIndex: any;
                collection: any;
                isKeySorting: any;
            }, e: any): void;
            onSortEnd?({ oldIndex, newIndex, collection, isKeySorting }: {
                oldIndex: any;
                newIndex: any;
                collection: any;
                isKeySorting: any;
            }, e: any): boolean | void;
        } | undefined;
    } | undefined;
    pagination?: boolean | (import("antd").PaginationProps & {
        align?: "left" | "center" | "right" | undefined;
        height?: number | undefined;
        pageIndex?: number | undefined;
        pageSize?: number | undefined;
        targetContainer?: string | HTMLElement | undefined;
        leftRender?: (({ table }: {
            table: any;
        }) => React.ReactNode) | undefined;
        rightRender?: (({ table }: {
            table: any;
        }) => React.ReactNode) | undefined;
        onBeforeChange?: ((page: number, pageSize?: number | undefined) => boolean | Promise<any>) | undefined;
    }) | undefined;
    request?: ((...args: any[]) => Promise<IObject | IObject[] | {
        total: number;
        record: IObject[];
        aggregate?: Record<string, Record<"min" | "max" | "avg" | "sum" | "count", string | number>> | undefined;
        summaryData?: Record<string, string | number> | undefined;
    }>) | undefined;
    queryResetIndex?: boolean | undefined;
    response?: ((res: any) => {
        total: number;
        record: IObject[];
        aggregate?: Record<string, Record<"min" | "max" | "avg" | "sum" | "count", string | number>> | undefined;
        summaryData?: Record<string, string | number> | undefined;
    }) | undefined;
    groupBy?: string | undefined;
    groupAggregatePosition?: "start" | "end" | undefined;
    aggregatePosition?: "start" | "end" | undefined;
    defaultExpand?: "all" | "first" | undefined;
    columnStateChange?: ((...args: any[]) => void) | undefined;
    dataIndexProps?: ({
        [key: string]: ColumnProps | ((column: ColumnProps) => ColumnProps);
    } | ((column: ColumnProps) => ColumnProps)) | undefined;
    align?: "left" | "center" | "right" | undefined;
    onDataLoad?: ((...args: any[]) => void) | undefined;
    fullyControlled?: boolean | undefined;
    aggregateStyle?: React.CSSProperties | undefined;
    optimize?: {
        vertical?: boolean | undefined;
    } | undefined;
    borderColor?: string | undefined;
    rowSelection?: {
        type: TableSelectionModel | TableSelectionModel[];
        keyField?: string | undefined;
        checkedField?: string | undefined;
        disabled?: ((row: any) => boolean) | undefined;
        autoCheckedChildren?: boolean | undefined;
    } | undefined;
    tableAlertRender?: boolean | ((params: {
        selectedRowKeys: (string | number)[];
        selectedRows: IObject[];
        onClear: Function;
    }) => React.ReactNode) | undefined;
    activeCellEditor?: "click" | "doubleClick" | undefined;
    autoCancelEditor?: boolean | undefined;
    subTable?: IObject<{
        dataSource: [string, (((row: any) => any[] | Promise<any[]>) | undefined)?];
        busKey?: string | undefined;
        busFields?: string[] | undefined;
    }> | undefined;
    disabled?: boolean | (({ row, dataIndex }: {
        row: any;
        dataIndex: any;
    }) => boolean) | undefined;
    readOnly?: boolean | (({ row, dataIndex }: {
        row: any;
        dataIndex: any;
    }) => boolean) | undefined;
    onBeforeEditCellKeyDown?: ((e: any, { rowIndex, columnIndex }: {
        rowIndex: any;
        columnIndex: any;
    }) => boolean | undefined) | undefined;
    onAfterEditCellKeyDown?: ((e: any, { rowIndex, columnIndex }: {
        rowIndex: any;
        columnIndex: any;
    }) => void) | undefined;
    headerTooltip?: boolean | undefined;
    tooltip?: boolean | ((params: {
        table: TableInstance;
        row: IObject;
        value: any;
        dataIndex: string;
        rowIndex: number;
        pageIndex: number;
        pageSize: number;
        onChange?: ((val: any) => void) | undefined;
        inGroup?: boolean | undefined;
    }) => React.ReactNode) | "render" | {
        overflow: boolean;
        type: ((params: {
            table: TableInstance;
            row: IObject;
            value: any;
            dataIndex: string;
            rowIndex: number;
            pageIndex: number;
            pageSize: number;
            onChange?: ((val: any) => void) | undefined;
            inGroup?: boolean | undefined;
        }) => React.ReactNode) | "render";
    } | undefined;
    columnSort?: boolean | undefined;
    local?: {
        noData?: string | undefined;
        addRow?: string | undefined;
    } | undefined;
} & Partial<{
    /**
     * @description       紧凑表格
     * @default           false
     */
    compact: boolean;
    /**
     * @description       表格延迟resize的毫秒数
     * @default           16
     */
    resizeDelay: number;
    /**
     * @description       是否加载中
     * @default           false
     */
    loading: boolean;
    /**
     * @description       配置request属性，是否自动加载数据
     * @default           true
     */
    autoLoad: boolean;
    /**
     * @description       是否树形列表
     * @default           false
     */
    isTree: boolean;
    /**
     * @description       是否显示单元格边框
     * @default           false
     */
    bordered: boolean;
    /**
     * @description       是否隐藏表头
     * @default           false
     */
    hiddenHeader: boolean;
    /**
     * @description       是否支持单击行选中checkbox
     * @default           false
     */
    rowChecked: boolean;
    /**
     * @description       点击数据行高亮选中行
     * @default           true
     */
    rowSelected: boolean;
    /**
     * @description       点击checkbox列高亮选中行
     * @default           false
     */
    checkboxSelected: boolean;
    /**
     * @description       是否启用虚拟滚动，建议开启；如果需要高度随内容自动撑开，设置false
     * @default           true
     */
    virtualScrolling: boolean;
    /**
     * @description       编辑状态，是否支持最后一行按"下方向键"及最后一列按"回车"或"tab"自动增加行
     * @default           false
     */
    keyBoardToAddRow: boolean;
    /**
     * @description       编辑状态，键盘事件的是否绑定在document上，注意多个Grid会产生冲突
     * @default           false
     */
    listenerOnDocument: boolean;
    /**
     * @description       是否开启记忆列状态功能
     * @default           true
     */
    remember: boolean;
}> & {
    id?: string | undefined;
}, "outRef"> & React.RefAttributes<import("@cscec/udp-core/src/interface/types/ts.lib").ICurrentObject<TableInstance>>>;
